@@ -4,4 +4,4 @@ setClass("cacorporateplus",representation(S="cabasicresults",
   Rprinccoord="matrix", Cprinccoord="matrix", Rstdcoord="matrix", Cstdcoord="matrix",
     inertiasum="numeric", inertias="matrix", inertias2="matrix",comps="matrix",
   printdims="numeric", maxaxes="numeric",catype="character",mj="numeric",mi="numeric",pcc="matrix",Jmass="matrix",
-Imass="matrix",Trend="matrix"))
+Imass="matrix",Trend="matrix",Z="matrix"))
